diff --git a/arch/nrf52/nrf52.ini b/arch/nrf52/nrf52.ini
index 606cabac6..d4e88af1f 100644
--- a/arch/nrf52/nrf52.ini
+++ b/arch/nrf52/nrf52.ini
@@ -17,7 +17,6 @@ build_flags =
-DLFS_NO_ASSERT ; Disable LFS assertions , see https://github.com/meshtastic/firmware/pull/3818
-DMESHTASTIC_EXCLUDE_AUDIO=1
-DMESHTASTIC_EXCLUDE_PAXCOUNTER=1
- -DMAX_NUM_NODES=80
build_src_filter =
${arduino_base.build_src_filter} - - - - - - - - - -
diff --git a/bin/device-install.bat b/bin/device-install.bat
index 7eb5c1b30..3ffca0b63 100755
--- a/bin/device-install.bat
+++ b/bin/device-install.bat
@@ -7,12 +7,19 @@ SET "DEBUG=0"
SET "PYTHON="
SET "WEB_APP=0"
SET "TFT_BUILD=0"
-SET "TFT8=0"
-SET "TFT16=0"
+SET "BIGDB8=0"
+SET "BIGDB16=0"
SET "ESPTOOL_BAUD=115200"
SET "ESPTOOL_CMD="
SET "LOGCOUNTER=0"
+@REM FIXME: Determine mcu from PlatformIO variant, this is unmaintainable.
+SET "S3=s3 v3 t-deck wireless-paper wireless-tracker station-g2 unphone"
+SET "C3=esp32c3"
+@REM FIXME: Determine flash size from PlatformIO variant, this is unmaintainable.
+SET "BIGDB_8MB=picomputer-s3 unphone seeed-sensecap-indicator crowpanel-esp32s3 heltec_capsule_sensor_v3 heltec-v3 heltec-vision-master-e213 heltec-vision-master-e290 heltec-vision-master-t190 heltec-wireless-paper heltec-wireless-tracker heltec-wsl-v3 icarus seeed-xiao-s3 tbeam-s3-core tracksenger"
+SET "BIGDB_16MB=t-deck mesh-tab t-energy-s3 dreamcatcher ESP32-S3-Pico m5stack-cores3 station-g2 t-eth-elite t-watch-s3"
+
GOTO getopts
:help
ECHO Flash image file to device, but first erasing and writing system information.
@@ -134,44 +141,36 @@ IF NOT "!FILENAME:-tft-=!"=="!FILENAME!" (
CALL :LOG_MESSAGE ERROR "Cannot enable WebUI (--web) and MUI." & GOTO eof
)
SET "TFT_BUILD=1"
- GOTO tft
) ELSE (
CALL :LOG_MESSAGE DEBUG "We are NOT working with a *-tft-* file. !FILENAME!"
- GOTO no_tft
)
-:tft
-SET "TFT8MB=picomputer-s3 unphone seeed-sensecap-indicator"
-FOR %%a IN (%TFT8MB%) DO (
+FOR %%a IN (%BIGDB_8MB%) DO (
IF NOT "!FILENAME:%%a=!"=="!FILENAME!" (
- @REM We are working with any of %TFT8MB%.
- SET "TFT8=1"
- GOTO end_loop_tft8mb
+ @REM We are working with any of %BIGDB_8MB%.
+ SET "BIGDB8=1"
+ GOTO end_loop_bigdb_8mb
)
)
-:end_loop_tft8mb
+:end_loop_bigdb_8mb
-SET "TFT16MB=t-deck"
-FOR %%a IN (%TFT16MB%) DO (
+FOR %%a IN (%BIGDB_16MB%) DO (
IF NOT "!FILENAME:%%a=!"=="!FILENAME!" (
- @REM We are working with any of %TFT16MB%.
- SET "TFT16=1"
- GOTO end_loop_tft16mb
+ @REM We are working with any of %BIGDB_16MB%.
+ SET "BIGDB16=1"
+ GOTO end_loop_bigdb_16mb
)
)
-:end_loop_tft16mb
+:end_loop_bigdb_16mb
-IF %TFT8% EQU 1 CALL :LOG_MESSAGE INFO "tft and MUI 8mb selected."
-IF %TFT16% EQU 1 CALL :LOG_MESSAGE INFO "tft and MUI 16mb selected."
-
-:no_tft
+IF %BIGDB8% EQU 1 CALL :LOG_MESSAGE INFO "BigDB 8mb partition selected."
+IF %BIGDB16% EQU 1 CALL :LOG_MESSAGE INFO "BigDB 16mb partition selected."
@REM Extract BASENAME from %FILENAME% for later use.
SET "BASENAME=!FILENAME:firmware-=!"
CALL :LOG_MESSAGE DEBUG "Computed firmware basename: !BASENAME!"
@REM Account for S3 and C3 board's different OTA partition.
-SET "S3=s3 v3 t-deck wireless-paper wireless-tracker station-g2 unphone"
FOR %%a IN (%S3%) DO (
IF NOT "!FILENAME:%%a=!"=="!FILENAME!" (
@REM We are working with any of %S3%.
@@ -180,7 +179,6 @@ FOR %%a IN (%S3%) DO (
)
)
-SET "C3=esp32c3"
FOR %%a IN (%C3%) DO (
IF NOT "!FILENAME:%%a=!"=="!FILENAME!" (
@REM We are working with any of %C3%.
@@ -209,14 +207,14 @@ CALL :LOG_MESSAGE DEBUG "Set SPIFFS_FILENAME to: !SPIFFS_FILENAME!"
SET "OTA_OFFSET=0x260000"
SET "SPIFFS_OFFSET=0x300000"
-@REM Offsets for MUI 8mb.
-IF %TFT8% EQU 1 IF %TFT_BUILD% EQU 1 (
+@REM Offsets for BigDB 8mb.
+IF %BIGDB8% EQU 1 (
SET "OTA_OFFSET=0x340000"
SET "SPIFFS_OFFSET=0x670000"
)
-@REM Offsets for MUI 16mb.
-IF %TFT16% EQU 1 IF %TFT_BUILD% EQU 1 (
+@REM Offsets for BigDB 16mb.
+IF %BIGDB16% EQU 1 (
SET "OTA_OFFSET=0x650000"
SET "SPIFFS_OFFSET=0xc90000"
)
diff --git a/src/mesh/mesh-pb-constants.h b/src/mesh/mesh-pb-constants.h
index f91c48560..1c86653dc 100644
--- a/src/mesh/mesh-pb-constants.h
+++ b/src/mesh/mesh-pb-constants.h
@@ -18,10 +18,30 @@
#define MAX_RX_TOPHONE 32
#endif
-/// max number of nodes allowed in the mesh
+/// max number of nodes allowed in the nodeDB
#ifndef MAX_NUM_NODES
+#if defined(ARCH_STM32WL)
+#define MAX_NUM_NODES 10
+#elif defined(ARCH_NRF52)
+#define MAX_NUM_NODES 80
+#elif defined(CONFIG_IDF_TARGET_ESP32S3)
+#include "Esp.h"
+static inline int get_max_num_nodes()
+{
+ uint32_t flash_size = ESP.getFlashChipSize() / (1024 * 1024); // Convert Bytes to MB
+ if (flash_size >= 15) {
+ return 250;
+ } else if (flash_size >= 7) {
+ return 200;
+ } else {
+ return 100;
+ }
+}
+#define MAX_NUM_NODES get_max_num_nodes()
+#else
#define MAX_NUM_NODES 100
#endif
+#endif
/// Max number of channels allowed
#define MAX_NUM_CHANNELS (member_size(meshtastic_ChannelFile, channels) / member_size(meshtastic_ChannelFile, channels[0]))
diff --git a/variants/CDEBYTE_E77-MBL/variant.h b/variants/CDEBYTE_E77-MBL/variant.h
index 7331dcedc..52801dac7 100644
--- a/variants/CDEBYTE_E77-MBL/variant.h
+++ b/variants/CDEBYTE_E77-MBL/variant.h
@@ -14,7 +14,6 @@ Do not expect a working Meshtastic device with this target.
#define _VARIANT_EBYTE_E77_
#define USE_STM32WLx
-#define MAX_NUM_NODES 10
#define LED_PIN PB4 // LED1
// #define LED_PIN PB3 // LED2
diff --git a/variants/crowpanel-esp32s3-5-epaper/platformio.ini b/variants/crowpanel-esp32s3-5-epaper/platformio.ini
index 7e95a5fcf..36816d616 100644
--- a/variants/crowpanel-esp32s3-5-epaper/platformio.ini
+++ b/variants/crowpanel-esp32s3-5-epaper/platformio.ini
@@ -5,6 +5,7 @@ board_build.flash_mode = qio
board_build.psram_type = opi
board_upload.flash_size = 8MB
board_upload.maximum_size = 8388608
+board_build.partitions = default_8MB.csv
board = esp32-s3-devkitc-1
;upload_port = /dev/ttyUSB0
board_level = extra
@@ -32,6 +33,7 @@ board_build.flash_mode = qio
board_build.psram_type = opi
board_upload.flash_size = 8MB
board_upload.maximum_size = 8388608
+board_build.partitions = default_8MB.csv
board = esp32-s3-devkitc-1
;upload_port = /dev/ttyUSB0
board_level = extra
@@ -59,6 +61,7 @@ board_build.flash_mode = qio
board_build.psram_type = opi
board_upload.flash_size = 8MB
board_upload.maximum_size = 8388608
+board_build.partitions = default_8MB.csv
board = esp32-s3-devkitc-1
;upload_port = /dev/ttyUSB0
board_level = extra
diff --git a/variants/diy/platformio.ini b/variants/diy/platformio.ini
index 229f48bbf..825c464a2 100644
--- a/variants/diy/platformio.ini
+++ b/variants/diy/platformio.ini
@@ -88,6 +88,7 @@ debug_tool = jlink
[env:t-energy-s3_e22]
extends = esp32s3_base
board = esp32-s3-devkitc-1
+board_build.partitions = default_16MB.csv
board_level = extra
board_upload.flash_size = 16MB ;Specify the FLASH capacity as 16MB
board_build.arduino.memory_type = qio_opi ;Enable internal PSRAM
@@ -100,4 +101,4 @@ build_flags =
-D BOARD_HAS_PSRAM
-D ARDUINO_USB_MODE=0
-D ARDUINO_USB_CDC_ON_BOOT=1
- -I variants/diy/t-energy-s3_e22
\ No newline at end of file
+ -I variants/diy/t-energy-s3_e22
diff --git a/variants/dreamcatcher/platformio.ini b/variants/dreamcatcher/platformio.ini
index c57849d96..6527d89be 100644
--- a/variants/dreamcatcher/platformio.ini
+++ b/variants/dreamcatcher/platformio.ini
@@ -1,6 +1,7 @@
[env:dreamcatcher] ; 2301, latest revision
extends = esp32s3_base
board = esp32s3box
+board_build.partitions = default_16MB.csv
board_level = extra
build_flags =
@@ -8,7 +9,7 @@ build_flags =
-D PRIVATE_HW
-D OTHERNET_DC_REV=2301
-I variants/dreamcatcher
- -DARDUINO_USB_CDC_ON_BOOT=1
+ -D ARDUINO_USB_CDC_ON_BOOT=1
lib_deps = ${esp32s3_base.lib_deps}
earlephilhower/ESP8266Audio@^1.9.9
@@ -17,6 +18,7 @@ lib_deps = ${esp32s3_base.lib_deps}
[env:dreamcatcher-2206]
extends = esp32s3_base
board = esp32s3box
+board_build.partitions = default_16MB.csv
board_level = extra
build_flags =
@@ -24,4 +26,4 @@ build_flags =
-D PRIVATE_HW
-D OTHERNET_DC_REV=2206
-I variants/dreamcatcher
- -DARDUINO_USB_CDC_ON_BOOT=1
\ No newline at end of file
+ -D ARDUINO_USB_CDC_ON_BOOT=1
diff --git a/variants/esp32-s3-pico/platformio.ini b/variants/esp32-s3-pico/platformio.ini
index 20a41ba56..69969c601 100644
--- a/variants/esp32-s3-pico/platformio.ini
+++ b/variants/esp32-s3-pico/platformio.ini
@@ -4,6 +4,7 @@ board_level = extra
extends = esp32s3_base
upload_protocol = esptool
board = esp32-s3-pico
+board_build.partitions = default_16MB.csv
board_upload.use_1200bps_touch = yes
board_upload.wait_for_upload_port = yes
diff --git a/variants/heltec_capsule_sensor_v3/platformio.ini b/variants/heltec_capsule_sensor_v3/platformio.ini
index b5ffb65c2..8d1c039c1 100644
--- a/variants/heltec_capsule_sensor_v3/platformio.ini
+++ b/variants/heltec_capsule_sensor_v3/platformio.ini
@@ -2,7 +2,7 @@
extends = esp32s3_base
board = heltec_wifi_lora_32_V3
board_check = true
-
+board_build.partitions = default_8MB.csv
build_flags =
${esp32s3_base.build_flags} -I variants/heltec_capsule_sensor_v3
-D HELTEC_CAPSULE_SENSOR_V3
diff --git a/variants/heltec_v3/platformio.ini b/variants/heltec_v3/platformio.ini
index e8f73e1ef..4be96b019 100644
--- a/variants/heltec_v3/platformio.ini
+++ b/variants/heltec_v3/platformio.ini
@@ -2,7 +2,7 @@
extends = esp32s3_base
board = heltec_wifi_lora_32_V3
board_check = true
-# Temporary until espressif creates a release with this new target
+board_build.partitions = default_8MB.csv
build_flags =
${esp32s3_base.build_flags} -D HELTEC_V3 -I variants/heltec_v3
- -DGPS_POWER_TOGGLE ; comment this line to disable triple press function on the user button to turn off gps entirely.
\ No newline at end of file
+ -D GPS_POWER_TOGGLE ; comment this line to disable triple press function on the user button to turn off gps entirely.
diff --git a/variants/heltec_vision_master_e213/platformio.ini b/variants/heltec_vision_master_e213/platformio.ini
index 6ba597200..4bed30324 100644
--- a/variants/heltec_vision_master_e213/platformio.ini
+++ b/variants/heltec_vision_master_e213/platformio.ini
@@ -1,8 +1,9 @@
[env:heltec-vision-master-e213]
extends = esp32s3_base
board = heltec_vision_master_e213
+board_build.partitions = default_8MB.csv
build_flags =
- ${esp32s3_base.build_flags}
+ ${esp32s3_base.build_flags}
-Ivariants/heltec_vision_master_e213
-DHELTEC_VISION_MASTER_E213
-DUSE_EINK
@@ -22,6 +23,7 @@ upload_speed = 115200
[env:heltec-vision-master-e213-inkhud]
extends = esp32s3_base, inkhud
board = heltec_vision_master_e213
+board_build.partitions = default_8MB.csv
build_src_filter =
${esp32_base.build_src_filter}
${inkhud.build_src_filter}
diff --git a/variants/heltec_vision_master_e290/platformio.ini b/variants/heltec_vision_master_e290/platformio.ini
index cfea81a7e..d28c2015b 100644
--- a/variants/heltec_vision_master_e290/platformio.ini
+++ b/variants/heltec_vision_master_e290/platformio.ini
@@ -2,6 +2,7 @@
[env:heltec-vision-master-e290]
extends = esp32s3_base
board = heltec_vision_master_e290
+board_build.partitions = default_8MB.csv
build_flags =
${esp32s3_base.build_flags}
-I variants/heltec_vision_master_e290
@@ -26,6 +27,7 @@ upload_speed = 115200
[env:heltec-vision-master-e290-inkhud]
extends = esp32s3_base, inkhud
board = heltec_vision_master_e290
+board_build.partitions = default_8MB.csv
build_src_filter =
${esp32_base.build_src_filter}
${inkhud.build_src_filter}
diff --git a/variants/heltec_vision_master_t190/platformio.ini b/variants/heltec_vision_master_t190/platformio.ini
index 0c504d62b..53b56f57d 100644
--- a/variants/heltec_vision_master_t190/platformio.ini
+++ b/variants/heltec_vision_master_t190/platformio.ini
@@ -1,11 +1,11 @@
[env:heltec-vision-master-t190]
extends = esp32s3_base
board = heltec_vision_master_t190
+board_build.partitions = default_8MB.csv
build_flags =
${esp32s3_base.build_flags}
-Ivariants/heltec_vision_master_t190
- -DHELTEC_VISION_MASTER_T190
- ; -D PRIVATE_HW
+ -DHELTEC_VISION_MASTER_T190
lib_deps =
${esp32s3_base.lib_deps}
lewisxhe/PCF8563_Library@^1.0.1
diff --git a/variants/heltec_wireless_paper/platformio.ini b/variants/heltec_wireless_paper/platformio.ini
index 9979e1c1d..bd25a932a 100644
--- a/variants/heltec_wireless_paper/platformio.ini
+++ b/variants/heltec_wireless_paper/platformio.ini
@@ -2,6 +2,7 @@
[env:heltec-wireless-paper]
extends = esp32s3_base
board = heltec_wifi_lora_32_V3
+board_build.partitions = default_8MB.csv
build_flags =
${esp32s3_base.build_flags}
-I variants/heltec_wireless_paper
@@ -23,6 +24,7 @@ upload_speed = 115200
[env:heltec-wireless-paper-inkhud]
extends = esp32s3_base, inkhud
board = heltec_wifi_lora_32_V3
+board_build.partitions = default_8MB.csv
build_src_filter =
${esp32_base.build_src_filter}
${inkhud.build_src_filter}
diff --git a/variants/heltec_wireless_paper_v1/platformio.ini b/variants/heltec_wireless_paper_v1/platformio.ini
index 2ce7559f9..ec5fe2408 100644
--- a/variants/heltec_wireless_paper_v1/platformio.ini
+++ b/variants/heltec_wireless_paper_v1/platformio.ini
@@ -2,6 +2,7 @@
extends = esp32s3_base
board_level = extra
board = heltec_wifi_lora_32_V3
+board_build.partitions = default_8MB.csv
build_flags =
${esp32s3_base.build_flags}
-I variants/heltec_wireless_paper_v1
diff --git a/variants/heltec_wireless_tracker/platformio.ini b/variants/heltec_wireless_tracker/platformio.ini
index 4f686d289..5c19c37e6 100644
--- a/variants/heltec_wireless_tracker/platformio.ini
+++ b/variants/heltec_wireless_tracker/platformio.ini
@@ -1,6 +1,7 @@
[env:heltec-wireless-tracker]
extends = esp32s3_base
board = heltec_wireless_tracker
+board_build.partitions = default_8MB.csv
upload_protocol = esptool
build_flags =
diff --git a/variants/heltec_wireless_tracker_V1_0/platformio.ini b/variants/heltec_wireless_tracker_V1_0/platformio.ini
index 5f512b816..08b0ae95c 100644
--- a/variants/heltec_wireless_tracker_V1_0/platformio.ini
+++ b/variants/heltec_wireless_tracker_V1_0/platformio.ini
@@ -2,6 +2,7 @@
extends = esp32s3_base
board_level = extra
board = heltec_wireless_tracker
+board_build.partitions = default_8MB.csv
upload_protocol = esptool
build_flags =
${esp32s3_base.build_flags} -I variants/heltec_wireless_tracker_V1_0
diff --git a/variants/heltec_wsl_v3/platformio.ini b/variants/heltec_wsl_v3/platformio.ini
index c95659156..bc3e6ada1 100644
--- a/variants/heltec_wsl_v3/platformio.ini
+++ b/variants/heltec_wsl_v3/platformio.ini
@@ -1,7 +1,8 @@
[env:heltec-wsl-v3]
extends = esp32s3_base
board = heltec_wifi_lora_32_V3
+board_build.partitions = default_8MB.csv
# Temporary until espressif creates a release with this new target
build_flags =
${esp32s3_base.build_flags} -D HELTEC_WSL_V3 -I variants/heltec_wsl_v3
- -DGPS_POWER_TOGGLE ; comment this line to disable triple press function on the user button to turn off gps entirely.
\ No newline at end of file
+ -D GPS_POWER_TOGGLE ; comment this line to disable triple press function on the user button to turn off gps entirely.
diff --git a/variants/icarus/platformio.ini b/variants/icarus/platformio.ini
index b1dc01fc1..b4ea125cf 100644
--- a/variants/icarus/platformio.ini
+++ b/variants/icarus/platformio.ini
@@ -4,6 +4,7 @@ board = icarus
board_level = extra
board_check = true
board_build.mcu = esp32s3
+board_build.partitions = default_8MB.csv
upload_protocol = esptool
upload_speed = 921600
platform_packages = platformio/framework-arduinoespressif32@https://github.com/PowerFeather/powerfeather-meshtastic-arduino-lib/releases/download/2.0.16a/esp32-2.0.16.zip
@@ -15,5 +16,4 @@ build_unflags =
build_flags =
${esp32s3_base.build_flags} -D PRIVATE_HW -I variants/icarus
-DBOARD_HAS_PSRAM
-
- -DARDUINO_USB_MODE=0
\ No newline at end of file
+ -DARDUINO_USB_MODE=0
diff --git a/variants/m5stack_cores3/platformio.ini b/variants/m5stack_cores3/platformio.ini
index fc73fabae..2253e75e2 100644
--- a/variants/m5stack_cores3/platformio.ini
+++ b/variants/m5stack_cores3/platformio.ini
@@ -3,6 +3,7 @@
extends = esp32s3_base
board = m5stack-cores3
board_check = true
+board_build.partitions = default_16MB.csv
upload_protocol = esptool
build_flags = ${esp32_base.build_flags}
diff --git a/variants/mesh-tab/platformio.ini b/variants/mesh-tab/platformio.ini
index 9e3429ac5..728fa5100 100644
--- a/variants/mesh-tab/platformio.ini
+++ b/variants/mesh-tab/platformio.ini
@@ -28,7 +28,6 @@ build_flags = ${esp32s3_base.build_flags}
-D USE_LOG_DEBUG
-D LOG_DEBUG_INC=\"DebugConfiguration.h\"
-D RADIOLIB_SPI_PARANOID=0
- -D MAX_NUM_NODES=250
-D MAX_THREADS=40
-D HAS_SCREEN=0
-D HAS_TFT=1
diff --git a/variants/picomputer-s3/platformio.ini b/variants/picomputer-s3/platformio.ini
index 7f769253c..df2d0dfdc 100644
--- a/variants/picomputer-s3/platformio.ini
+++ b/variants/picomputer-s3/platformio.ini
@@ -2,6 +2,7 @@
extends = esp32s3_base
board = bpi_picow_esp32_s3
board_check = true
+board_build.partitions = default_8MB.csv
;OpenOCD flash method
;upload_protocol = esp-builtin
;Normal method
@@ -22,7 +23,6 @@ build_src_filter =
[env:picomputer-s3-tft]
extends = env:picomputer-s3
-board_build.partitions = default_8MB.csv ; just for test
build_flags =
${env:picomputer-s3.build_flags}
@@ -35,7 +35,6 @@ build_flags =
-D INPUTDRIVER_MATRIX_TYPE=1
-D USE_PIN_BUZZER=PIN_BUZZER
-D USE_SX127x
- -D MAX_NUM_NODES=200
-D HAS_SCREEN=0
-D HAS_TFT=1
-D RAM_SIZE=1024
diff --git a/variants/rak3172/variant.h b/variants/rak3172/variant.h
index 21de65b2c..dd12fe393 100644
--- a/variants/rak3172/variant.h
+++ b/variants/rak3172/variant.h
@@ -7,6 +7,5 @@ Do not expect a working Meshtastic device with this target.
#define _VARIANT_RAK3172_
#define USE_STM32WLx
-#define MAX_NUM_NODES 10
#endif
\ No newline at end of file
diff --git a/variants/seeed-sensecap-indicator/platformio.ini b/variants/seeed-sensecap-indicator/platformio.ini
index d351713d7..da11953b7 100644
--- a/variants/seeed-sensecap-indicator/platformio.ini
+++ b/variants/seeed-sensecap-indicator/platformio.ini
@@ -6,6 +6,7 @@ platform_packages =
board = seeed-sensecap-indicator
board_check = true
+board_build.partitions = default_8MB.csv
upload_protocol = esptool
build_flags = ${esp32_base.build_flags}
@@ -32,7 +33,6 @@ lib_deps = ${esp32s3_base.lib_deps}
extends = env:seeed-sensecap-indicator
board_level = main
upload_speed = 460800
-board_build.partitions = default_8MB.csv ; must be here for some reason, board.json is not enough !?
build_flags =
${env:seeed-sensecap-indicator.build_flags}
@@ -46,7 +46,6 @@ build_flags =
-D INPUTDRIVER_BUTTON_TYPE=38
-D HAS_TELEMETRY=0
-D CONFIG_DISABLE_HAL_LOCKS=1
- -D MAX_NUM_NODES=250
-D HAS_SCREEN=0
-D HAS_TFT=1
-D DISPLAY_SET_RESOLUTION
diff --git a/variants/seeed_xiao_s3/platformio.ini b/variants/seeed_xiao_s3/platformio.ini
index 3d10d7136..9d935e2e0 100644
--- a/variants/seeed_xiao_s3/platformio.ini
+++ b/variants/seeed_xiao_s3/platformio.ini
@@ -2,7 +2,7 @@
extends = esp32s3_base
board = seeed-xiao-s3
board_check = true
-board_build.mcu = esp32s3
+board_build.partitions = default_8MB.csv
upload_protocol = esptool
upload_speed = 921600
lib_deps =
diff --git a/variants/station-g2/platformio.ini b/variants/station-g2/platformio.ini
index b674c8bae..4ddd28f1c 100755
--- a/variants/station-g2/platformio.ini
+++ b/variants/station-g2/platformio.ini
@@ -2,6 +2,7 @@
extends = esp32s3_base
board = station-g2
board_check = true
+board_build.partitions = default_16MB.csv
board_build.mcu = esp32s3
upload_protocol = esptool
;upload_port = /dev/ttyACM0
@@ -13,6 +14,6 @@ build_unflags =
-DARDUINO_USB_MODE=1
build_flags =
${esp32s3_base.build_flags} -D STATION_G2 -I variants/station-g2
- -DBOARD_HAS_PSRAM
+ -DBOARD_HAS_PSRAM
-DSTATION_G2
- -DARDUINO_USB_MODE=0
\ No newline at end of file
+ -DARDUINO_USB_MODE=0
diff --git a/variants/t-deck/platformio.ini b/variants/t-deck/platformio.ini
index a0005c9c6..4671a5a9b 100644
--- a/variants/t-deck/platformio.ini
+++ b/variants/t-deck/platformio.ini
@@ -3,6 +3,7 @@
extends = esp32s3_base
board = t-deck
board_check = true
+board_build.partitions = default_16MB.csv
upload_protocol = esptool
build_flags = ${esp32s3_base.build_flags}
@@ -20,7 +21,6 @@ lib_deps = ${esp32s3_base.lib_deps}
[env:t-deck-tft]
extends = env:t-deck
-board_build.partitions = default_16MB.csv
build_flags =
${env:t-deck.build_flags}
@@ -38,7 +38,6 @@ build_flags =
-D INPUTDRIVER_ENCODER_DOWN=15
-D INPUTDRIVER_ENCODER_BTN=0
-D INPUTDRIVER_BUTTON_TYPE=0
- -D MAX_NUM_NODES=250
-D HAS_SDCARD
-D HAS_SCREEN=0
-D HAS_TFT=1
diff --git a/variants/t-eth-elite/platformio.ini b/variants/t-eth-elite/platformio.ini
index 8c2f3bc37..ec6c82a5d 100644
--- a/variants/t-eth-elite/platformio.ini
+++ b/variants/t-eth-elite/platformio.ini
@@ -2,11 +2,12 @@
extends = esp32s3_base
board = esp32s3box
board_check = true
+board_build.partitions = default_16MB.csv
build_flags =
${esp32s3_base.build_flags}
-D T_ETH_ELITE
-I variants/t-eth-elite
- -DGPS_POWER_TOGGLE ; comment this line to disable triple press function on the user button to turn off gps entirely.
+ -D GPS_POWER_TOGGLE ; comment this line to disable triple press function on the user button to turn off gps entirely.
lib_ignore =
Ethernet
diff --git a/variants/t-watch-s3/platformio.ini b/variants/t-watch-s3/platformio.ini
index 8f48cf6c4..f98237943 100644
--- a/variants/t-watch-s3/platformio.ini
+++ b/variants/t-watch-s3/platformio.ini
@@ -3,6 +3,7 @@
extends = esp32s3_base
board = t-watch-s3
board_check = true
+board_build.partitions = default_16MB.csv
upload_protocol = esptool
build_flags = ${esp32_base.build_flags}
diff --git a/variants/tbeam-s3-core/platformio.ini b/variants/tbeam-s3-core/platformio.ini
index e50d506b9..a7bdf963f 100644
--- a/variants/tbeam-s3-core/platformio.ini
+++ b/variants/tbeam-s3-core/platformio.ini
@@ -2,6 +2,7 @@
[env:tbeam-s3-core]
extends = esp32s3_base
board = tbeam-s3-core
+board_build.partitions = default_8MB.csv
board_check = true
lib_deps =
diff --git a/variants/tracksenger/platformio.ini b/variants/tracksenger/platformio.ini
index 796a3b7d5..b36b9c45a 100644
--- a/variants/tracksenger/platformio.ini
+++ b/variants/tracksenger/platformio.ini
@@ -1,6 +1,7 @@
[env:tracksenger]
extends = esp32s3_base
board = heltec_wireless_tracker
+board_build.partitions = default_8MB.csv
upload_protocol = esp-builtin
build_flags =
@@ -16,6 +17,7 @@ lib_deps =
[env:tracksenger-lcd]
extends = esp32s3_base
board = heltec_wireless_tracker
+board_build.partitions = default_8MB.csv
upload_protocol = esp-builtin
build_flags =
@@ -31,6 +33,7 @@ lib_deps =
[env:tracksenger-oled]
extends = esp32s3_base
board = heltec_wireless_tracker
+board_build.partitions = default_8MB.csv
upload_protocol = esp-builtin
build_flags =
diff --git a/variants/unphone/platformio.ini b/variants/unphone/platformio.ini
index 88f6e7469..18efbb157 100644
--- a/variants/unphone/platformio.ini
+++ b/variants/unphone/platformio.ini
@@ -3,6 +3,7 @@
[env:unphone]
extends = esp32s3_base
board = unphone
+board_build.partitions = default_8MB.csv
upload_speed = 921600
monitor_speed = 115200
monitor_filters = esp32_exception_decoder
@@ -32,7 +33,6 @@ lib_deps = ${esp32s3_base.lib_deps}
[env:unphone-tft]
extends = env:unphone
-board_build.partitions = default_8MB.csv
build_flags =
${env:unphone.build_flags}
-D MESHTASTIC_EXCLUDE_CANNEDMESSAGES=1
@@ -42,7 +42,6 @@ build_flags =
-D MESHTASTIC_EXCLUDE_SERIAL=1
-D MESHTASTIC_EXCLUDE_SOCKETAPI=1
-D INPUTDRIVER_BUTTON_TYPE=21
- -D MAX_NUM_NODES=200
-D MAX_THREADS=40
-D HAS_SCREEN=0
-D HAS_TFT=1
diff --git a/variants/wio-e5/variant.h b/variants/wio-e5/variant.h
index ac92915bb..1de424d1d 100644
--- a/variants/wio-e5/variant.h
+++ b/variants/wio-e5/variant.h
@@ -13,7 +13,6 @@ Do not expect a working Meshtastic device with this target.
#define _VARIANT_WIOE5_
#define USE_STM32WLx
-#define MAX_NUM_NODES 10
#define LED_PIN PB5
#define LED_STATE_ON 1
diff --git a/bin/device-install.sh b/bin/device-install.sh
index 56e1abdb2..b5322b9d1 100755
--- a/bin/device-install.sh
+++ b/bin/device-install.sh
@@ -2,9 +2,48 @@
PYTHON=${PYTHON:-$(which python3 python | head -n 1)}
WEB_APP=false
-TFT8=false
-TFT16=false
TFT_BUILD=false
+MCU=""
+
+# Variant groups
+BIGDB_8MB=(
+ "picomputer-s3"
+ "unphone"
+ "seeed-sensecap-indicator"
+ "crowpanel-esp32s3"
+ "heltec_capsule_sensor_v3"
+ "heltec-v3"
+ "heltec-vision-master-e213"
+ "heltec-vision-master-e290"
+ "heltec-vision-master-t190"
+ "heltec-wireless-paper"
+ "heltec-wireless-tracker"
+ "heltec-wsl-v3"
+ "icarus"
+ "seeed-xiao-s3"
+ "tbeam-s3-core"
+ "tracksenger"
+)
+BIGDB_16MB=(
+ "t-deck"
+ "mesh-tab"
+ "t-energy-s3"
+ "dreamcatcher"
+ "ESP32-S3-Pico"
+ "m5stack-cores3"
+ "station-g2"
+ "t-eth-elite"
+ "t-watch-s3"
+)
+S3_VARIANTS=(
+ "s3"
+ "-v3"
+ "t-deck"
+ "wireless-paper"
+ "wireless-tracker"
+ "station-g2"
+ "unphone"
+)
# Determine the correct esptool command to use
if "$PYTHON" -m esptool version >/dev/null 2>&1; then
@@ -78,21 +117,13 @@ if [[ $FILENAME != firmware-* ]]; then
exit 1
fi
-# Check if FILENAME contains "-tft-" and set target partitionScheme accordingly.
+# Check if FILENAME contains "-tft-" and prevent web/mui comingling.
if [[ ${FILENAME//-tft-/} != "$FILENAME" ]]; then
TFT_BUILD=true
if [[ $WEB_APP == true ]] && [[ $TFT_BUILD == true ]]; then
echo "Cannot enable WebUI (--web) and MUI."
exit 1
fi
-
- if [[ $FILENAME == *"picomputer-s3"* || $FILENAME == *"unphone"* || $FILENAME == *"seeed-sensecap-indicator"* ]]; then
- TFT8=true
- fi
-
- if [[ $FILENAME == *"t-deck"* ]]; then
- TFT16=true
- fi
fi
# Extract BASENAME from %FILENAME% for later use.
@@ -105,20 +136,31 @@ if [ -f "${FILENAME}" ] && [ -n "${FILENAME##*"update"*}" ]; then
# Default OTA Offset
OTA_OFFSET=0x260000
- # littlefs* offset for MUI 8mb and OTA OFFSET.
- if [ "$TFT8" = true ] && [ "$TFT_BUILD" = true ]; then
- OFFSET=0x670000
- OTA_OFFSET=0x340000
- fi
+ # littlefs* offset for BigDB 8mb and OTA OFFSET.
+ for variant in "${BIGDB_8MB[@]}"; do
+ if [ -n "${FILENAME##*"$variant"*}" ]; then
+ OFFSET=0x670000
+ OTA_OFFSET=0x340000
+ fi
+ done
- # littlefs* offset for MUI 16mb and OTA OFFSET.
- if [ "$TFT16" = true ] && [ "$TFT_BUILD" = true ]; then
- OFFSET=0xc90000
- OTA_OFFSET=0x650000
- fi
+ # littlefs* offset for BigDB 16mb and OTA OFFSET.
+ for variant in "${BIGDB_16MB[@]}"; do
+ if [ -n "${FILENAME##*"$variant"*}" ]; then
+ OFFSET=0xc90000
+ OTA_OFFSET=0x650000
+ fi
+ done
# Account for S3 board's different OTA partition
- if [ -n "${FILENAME##*"s3"*}" ] && [ -n "${FILENAME##*"-v3"*}" ] && [ -n "${FILENAME##*"t-deck"*}" ] && [ -n "${FILENAME##*"wireless-paper"*}" ] && [ -n "${FILENAME##*"wireless-tracker"*}" ] && [ -n "${FILENAME##*"station-g2"*}" ] && [ -n "${FILENAME##*"unphone"*}" ]; then
+ # FIXME: Use PlatformIO info to determine MCU type, this is unmaintainable
+ for variant in "${S3_VARIANTS[@]}"; do
+ if [ -n "${FILENAME##*"$variant"*}" ]; then
+ MCU="esp32s3"
+ fi
+ done
+
+ if [ "$MCU" != "esp32s3" ]; then
if [ -n "${FILENAME##*"esp32c3"*}" ]; then
OTAFILE=bleota.bin
else